@@ -1,5 +1,5 @@
 from dbt.adapters.trino.connections import TrinoConnectionManager  # noqa
-from dbt.adapters.trino.connections import TrinoCredentials
+from dbt.adapters.trino.connections import TrinoCredentialsFactory
 from dbt.adapters.trino.column import TrinoColumn  # noqa
 from dbt.adapters.trino.impl import TrinoAdapter
 
@@ -9,5 +9,5 @@ from dbt.include import trino
 
 Plugin = AdapterPlugin(
     adapter=TrinoAdapter,
-    credentials=TrinoCredentials,
+    credentials=TrinoCredentialsFactory,
     include_path=trino.PACKAGE_PATH)
